Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/dataknobs_common/exceptions.py | DataknobsError | 3 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | ValidationError | 0 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | ConfigurationError | 0 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | ResourceError | 0 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | NotFoundError | 0 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | OperationError | 0 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | ConcurrencyError | 0 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | SerializationError | 0 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | TimeoutError | 0 | 0 | 0 | 100%
src/dataknobs_common/exceptions.py | (no class) | 20 | 0 | 0 | 100%
src/dataknobs_common/registry.py | Registry | 47 | 47 | 0 | 0%
src/dataknobs_common/registry.py | CachedRegistry | 31 | 31 | 0 | 0%
src/dataknobs_common/registry.py | AsyncRegistry | 47 | 47 | 0 | 0%
src/dataknobs_common/registry.py | (no class) | 49 | 0 | 0 | 100%
src/dataknobs_common/serialization.py | Serializable | 2 | 2 | 0 | 0%
src/dataknobs_common/serialization.py | (no class) | 40 | 25 | 0 | 38%
Total |  | 239 | 152 | 0 | 36%

No items found using the specified filter.